Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to Amazon Macie.

Actions, resources, and condition keys for Amazon Macie - Service Authorization Reference

# Actions, resources, and condition keys for Amazon Macie

Amazon Macie (service prefix: `macie2` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions defined by Amazon Macie
- Resource types defined by Amazon Macie
- Condition keys for Amazon Macie

## Actions defined by Amazon Macie

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see The actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
AcceptInvitation | Grants permission to accept an Amazon Macie membership invitation | Write |  |  |
BatchGetCustomDataIdentifiers | Grants permission to retrieve information about one or more custom data identifiers | Read | CustomDataIdentifier* |  |
CreateClassificationJob | Grants permission to create and define the settings for a classification job | Write | ClassificationJob* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateCustomDataIdentifier | Grants permission to create and define the settings for a custom data identifier | Write | CustomDataIdentifier* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateFindingsFilter | Grants permission to create and define the settings for a findings filter | Write | FindingsFilter* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateInvitations | Grants permission to send an Amazon Macie membership invitation | Write |  |  |
CreateMember | Grants permission to associate an account with an Amazon Macie master account | Write | Member* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateSampleFindings | Grants permission to create sample findings | Write |  |  |
DeclineInvitations | Grants permission to decline Amazon Macie membership invitations | Write |  |  |
DeleteCustomDataIdentifier | Grants permission to delete a custom data identifier | Write | CustomDataIdentifier* |  |
DeleteFindingsFilter | Grants permission to delete a findings filter | Write | FindingsFilter* |  |
DeleteInvitations | Grants permission to delete Amazon Macie membership invitations | Write |  |  |
DeleteMember | Grants permission to delete the association between an Amazon Macie master account and an account | Write | Member* |  |
DescribeBuckets | Grants permission to retrieve statistical and other data about S3 buckets that Amazon Macie monitors and analyzes | Read |  |  |
DescribeClassificationJob | Grants permission to retrieve information about the status and settings for a classification job | Read | ClassificationJob* |  |
DescribeOrganizationConfiguration | Grants permission to retrieve information about the Amazon Macie configuration settings for an AWS organization | Read |  |  |
DisableMacie | Grants permission to disable an Amazon Macie account, which also deletes Macie resources for the account | Write |  |  |
DisableOrganizationAdminAccount | Grants permission to disable an account as a delegated administrator of Amazon Macie for an AWS organization | Write |  |  |
DisassociateFromMasterAccount | Grants an Amazon Macie member account with permission to disassociate from its master account | Write |  |  |
DisassociateMember | Grants an Amazon Macie master account with permission to disassociate from a member account | Write | Member* |  |
EnableMacie | Grants permission to enable and specify the configuration settings for a new Amazon Macie account | Write |  |  |
EnableOrganizationAdminAccount | Grants permission to enable an account as a delegated administrator of Amazon Macie for an AWS organization | Write |  |  |
GetBucketStatistics | Grants permission to retrieve aggregated statistical data for all the S3 buckets that Amazon Macie monitors and analyzes | Read |  |  |
GetClassificationExportConfiguration | Grants permission to retrieve the settings for exporting data classification results | Read |  |  |
GetCustomDataIdentifier | Grants permission to retrieve information about the settings for a custom data identifier | Read | CustomDataIdentifier* |  |
GetFindingStatistics | Grants permission to retrieve aggregated statistical data about findings | Read |  |  |
GetFindings | Grants permission to retrieve information about one or more findings | Read |  |  |
GetFindingsFilter | Grants permission to retrieve information about the settings for a findings filter | Read | FindingsFilter* |  |
GetInvitationsCount | Grants permission to retrieve the count of Amazon Macie membership invitations that were received by an account | Read |  |  |
GetMacieSession | Grants permission to retrieve information about the status and configuration settings for an Amazon Macie account | Read |  |  |
GetMasterAccount | Grants permission to retrieve information about the Amazon Macie master account for an account | Read |  |  |
GetMember | Grants permission to retrieve information about an account that's associated with an Amazon Macie master account | Read | Member* |  |
GetUsageStatistics | Grants permission to retrieve quotas and aggregated usage data for one or more accounts | Read |  |  |
GetUsageTotals | Grants permission to retrieve aggregated usage data for an account | Read |  |  |
ListClassificationJobs | Grants permission to retrieve information about the status and settings for one or more classification jobs | List |  |  |
ListCustomDataIdentifiers | Grants permission to retrieve information about all custom data identifiers | List |  |  |
ListFindings | Grants permission to retrieve a subset of information about one or more findings | List |  |  |
ListFindingsFilters | Grants permission to retrieve information about all findings filters | List |  |  |
ListInvitations | Grants permission to retrieve information about all the Amazon Macie membership invitations that were received by an account | List |  |  |
ListMembers | Grants permission to retrieve information about all the accounts that are associated with an Amazon Macie master account | List |  |  |
ListOrganizationAdminAccounts | Grants permission to retrieve information about the delegated, Amazon Macie administrator account for an AWS organization | List |  |  |
ListTagsForResource | Grants permission to retrieve the tags for an Amazon Macie resource or member account | List |  |  |
PutClassificationExportConfiguration | Grants permission to create or update the settings for exporting data classification results | Write |  |  |
TagResource | Grants permission to add or update the tags for an Amazon Macie resource or member account | Tagging |  | aws:RequestTag/${TagKey} aws:TagKeys |
TestCustomDataIdentifier | Grants permission to test a custom data identifier | Write |  |  |
UntagResource | Grants permission to remove tags from an Amazon Macie resource or member account | Tagging |  | aws:TagKeys |
UpdateClassificationJob | Grants permission to cancel a classification job | Write | ClassificationJob* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
UpdateFindingsFilter | Grants permission to update the settings for a findings filter | Write | FindingsFilter* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
UpdateMacieSession | Grants permission to suspend or re-enable an Amazon Macie account, or update the configuration settings for a Macie account | Write |  |  |
UpdateMemberSession | Grants an Amazon Macie master account with permission to suspend or re-enable a member account | Write |  |  |
UpdateOrganizationConfiguration | Grants permission to update Amazon Macie configuration settings for an AWS organization | Write |  |  |

## Resource types defined by Amazon Macie

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see The resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
ClassificationJob | `arn:$ { Partition}:macie2:$ { Region}:$ { Account}:classification-job/$ { ResourceId}` | aws:ResourceTag/${TagKey}
CustomDataIdentifier | `arn:$ { Partition}:macie2:$ { Region}:$ { Account}:custom-data-identifier/$ { ResourceId}` | aws:ResourceTag/${TagKey}
FindingsFilter | `arn:$ { Partition}:macie2:$ { Region}:$ { Account}:findings-filter/$ { ResourceId}` | aws:ResourceTag/${TagKey}
Member | `arn:$ { Partition}:macie2:$ { Region}:$ { Account}:member/$ { ResourceId}` | aws:ResourceTag/${TagKey}

## Condition keys for Amazon Macie

Amazon Macie defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see The condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | Filters access based on the presence of tag key-value pairs in the request | String
aws:ResourceTag/${TagKey} | Filters access based on tag key-value pairs that are associated with the resource | String
aws:TagKeys | Filters access based on the presence of tag keys in the request | String

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.